﻿package org.shokai.motion.linetrace{
	import flash.display.Sprite;
	import flash.display.MovieClip;
	public class MoveController {
		/* 点と点の間の分割量 */
		public var partition:uint;
		
		/* 移動するポイントのリスト */
		public var points:Array;
		
		/* 点の総数 */
		public var total:Number;
		
		public function MoveController(partition:uint = 10) {
			this.partition = partition
			points = new Array();
			total = 0;
		}
		
		/* 点を追加 */
		public function addPoint(x:Number, y:Number, rotation:Number):Number{
			this.points.push(new RotPoint(x, y, rotation));
			this.total = 1+this.partition*(this.points.length-1);
			return total;
		}
		
		/* 線を表示する */
		public function drawLines(target:Sprite, thickness:Number = 1, color:uint = 0xFF0000, alpha:Number = 1.0):void{
			if(!points.length > 0) return;
			target.graphics.lineStyle(thickness, color, alpha);
			var p:RotPoint = points[0];
			target.graphics.moveTo(p.x, p.y);
			for(var i:int = 1; i < points.length; i++){
				p = points[i];
				target.graphics.lineTo(p.x, p.y);
			}
		}
		
		/* 点を表示する */
		public function drawPoints(target:Sprite, size:Number = 2, color:uint = 0x0000FF, alpha:Number = 1.0):void {
			if(!points.length > 0) return;
			target.graphics.lineStyle(0, 0, 0);
			target.graphics.beginFill(color, alpha);
			var p:RotPoint;
			for(var i:int = 0; i < total; i++){
				p = getPoint(i);
				target.graphics.lineTo(p.x, p.y);
				target.graphics.drawCircle(p.x, p.y, size);
			}
		}
		
		/* 指定位置の座標を取得 */
		public function getPoint(position:uint):RotPoint {
			if(total <= position || position < 0) return new RotPoint(); // この点は出ねえよ
			if(total-1 == position){ // 最後の点の時
				var p:RotPoint = points[points.length-1];
				return p;
			}
			else{
				var line:int = Math.floor(position/partition); // どの辺か
				var i:int = position%partition; // どの分割位置か
				var pb:RotPoint = points[line+1];
				var pa:RotPoint = points[line];
				var x:Number = (pb.x-pa.x)/partition*i+pa.x; // 辺上での位置を計算
				var y:Number = (pb.y-pa.y)/partition*i+pa.y;
				var rotation:Number = (pb.rotation-pa.rotation)/partition*i+pa.rotation;
				return new RotPoint(x,y,rotation);
			}
		}
		
		/* 指定位置にMCを移動させる */
		public function moveMC(mc:MovieClip, pos:int):RotPoint{
			var p:RotPoint = getPoint(pos);
			mc.x = p.x;
			mc.y = p.y;
			mc.rotation = p.rotation;
			return p;
		}
	}

}